"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.revert = exports.inject = void 0;
var _fs = _interopRequireDefault(require("fs"));
var _path = require("path");
var _es6Template = _interopRequireDefault(require("es6-template"));
var _semver = _interopRequireDefault(require("semver"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const tmplPath = (0, _path.join)(__dirname, 'injectDevToolsMiddleware.tmpl.js');
const tmplPathInDev = (0, _path.join)(__dirname, '../lib/injectDevToolsMiddleware.tmpl.js');
const template = _fs.default.readFileSync(_fs.default.existsSync(tmplPath) ? tmplPath : tmplPathInDev, 'utf-8');
const name = 'react-native-debugger-patch';
const startFlag = `/* ${name} start */`;
const endFlag = `/* ${name} end */`;
const rnFlags = {
  '0.50.0-rc.0': {
    target: 'react-native',
    dir: 'local-cli/server/middleware',
    file: 'getDevToolsMiddleware.js',
    keyFunc: 'launchChromeDevTools',
    func: "function launchChromeDevTools(port, args = '') {",
    replaceFunc: "function launchChromeDevTools(port, args = '', skipRNDebugger) {",
    funcCall: '(port, args, true)',
    args: "'localhost&port=' + port + '&args=' + args"
  },
  '0.53.0': {
    target: 'react-native',
    dir: 'local-cli/server/middleware',
    file: 'getDevToolsMiddleware.js',
    keyFunc: 'launchChromeDevTools',
    func: "function launchChromeDevTools(host, args = '') {",
    replaceFunc: "function launchChromeDevTools(host, args = '', skipRNDebugger) {",
    funcCall: '(host, args, true)',
    args: "'localhost&port=' + (host && host.split(':')[1] || '8081') + '&args=' + args"
  },
  '0.59.0-rc.0': [{
    target: '@react-native-community/cli',
    dir: 'build/commands/server/middleware',
    file: 'getDevToolsMiddleware.js',
    keyFunc: 'launchChromeDevTools',
    func: "function launchChromeDevTools(port, args = '') {",
    replaceFunc: "function launchChromeDevTools(port, args = '', skipRNDebugger) {",
    funcCall: '(port, args, true)',
    args: "'localhost&port=' + port + '&args=' + args"
  }, {
    target: '@react-native-community/cli',
    // 3.0.0 alpha
    dir: 'build/commands/server/middleware',
    file: 'getDevToolsMiddleware.js',
    keyFunc: 'launchDevTools',
    func: 'function launchDevTools({\n  port,\n  watchFolders\n}, isDebuggerConnected) {',
    replaceFunc: 'function launchDevTools({port, watchFolders},' + ' isDebuggerConnected, skipRNDebugger) {',
    funcCall: '({port, watchFolders}, isDebuggerConnected, true)',
    args: "'localhost&port=' + port + '&watchFolders=' + " + 'watchFolders.map(f => `"${f}"`).join(\',\')'
  }, {
    target: '@react-native-community/cli',
    // 3.0.0
    dir: 'build/commands/server/middleware',
    file: 'getDevToolsMiddleware.js',
    keyFunc: 'launchDefaultDebugger',
    func: "function launchDefaultDebugger(host, port, args = '') {",
    replaceFunc: "function launchDefaultDebugger(host, port, args = '', skipRNDebugger) {",
    funcCall: '(host, port, args, true)',
    args: "host + '&port=' + port + '&args=' + args"
  }],
  '0.62.0-rc.0': [
  // Tested ~ 0.71.x
  {
    target: '@react-native-community/cli-server-api',
    dir: 'build',
    file: 'devToolsMiddleware.js',
    keyFunc: 'launchDefaultDebugger',
    func: "function launchDefaultDebugger(host, port, args = '') {",
    replaceFunc: "function launchDefaultDebugger(host, port, args = '', skipRNDebugger) {",
    funcCall: '(host, port, args, true)',
    args: "(host || 'localhost') + '&port=' + port + '&args=' + args"
  }]
};
const flags = {
  'react-native': rnFlags,
  'react-native-tvos': rnFlags,
  'react-native-macos': {
    '0.0.0': {
      target: 'react-native-macos',
      dir: 'local-cli/server/middleware',
      file: 'getDevToolsMiddleware.js',
      keyFunc: 'launchChromeDevTools',
      func: 'function launchChromeDevTools(port) {',
      replaceFunc: 'function launchChromeDevTools(port, skipRNDebugger) {',
      funcCall: '(port, true)',
      args: "'localhost&port=' + port"
    }
  },
  // react-native
  default: {
    target: 'react-native',
    dir: 'local-cli/server/middleware',
    file: 'getDevToolsMiddleware.js',
    keyFunc: 'launchChromeDevTools',
    func: 'function launchChromeDevTools(port) {',
    replaceFunc: 'function launchChromeDevTools(port, skipRNDebugger) {',
    funcCall: '(port, true)',
    args: "'localhost&port=' + port"
  }
};
const getModuleInfo = (modulePath, moduleName) => {
  const pkg = JSON.parse(_fs.default.readFileSync((0, _path.join)(modulePath, moduleName, 'package.json'))); // eslint-disable-line
  return {
    version: pkg.version,
    name: pkg.name
  };
};
function getFlag(moduleName, version) {
  const list = flags[moduleName || 'react-native'] || {};
  const versions = Object.keys(list);
  let flag = flags.default;
  for (let i = 0; i < versions.length; i++) {
    if (_semver.default.gte(version, versions[i])) {
      flag = list[versions[i]];
    }
  }
  return flag;
}
const injectCode = (modulePath, {
  keyFunc,
  func: funcFlag,
  replaceFunc: replaceFuncFlag,
  funcCall,
  args,
  target,
  dir,
  file
}) => {
  const filePath = (0, _path.join)(modulePath, target, dir, file);
  if (!_fs.default.existsSync(filePath)) return false;
  const code = (0, _es6Template.default)(template, {
    startFlag,
    replaceFuncFlag,
    keyFunc,
    funcCall,
    endFlag,
    args
  });
  const middlewareCode = _fs.default.readFileSync(filePath, 'utf-8');
  let start = middlewareCode.indexOf(startFlag);
  let end = middlewareCode.indexOf(endFlag) + endFlag.length;
  // already injected
  if (start > -1 && middlewareCode.indexOf(replaceFuncFlag) === -1) {
    start = -1;
    end = -1;
  }
  if (start === -1) {
    start = middlewareCode.indexOf(funcFlag);
    end = start + funcFlag.length;
  }
  if (start === -1) return false;
  _fs.default.writeFileSync(filePath, middlewareCode.substr(0, start) + code + middlewareCode.substr(end, middlewareCode.length));
  return true;
};
const inject = (modulePath, moduleName) => {
  const info = getModuleInfo(modulePath, moduleName);
  const flagList = getFlag(info.name, info.version);
  if (Array.isArray(flagList)) {
    flagList.some(flag => injectCode(modulePath, flag));
  } else {
    injectCode(modulePath, flagList);
  }
  return true;
};
exports.inject = inject;
const revertCode = (modulePath, {
  func: funcFlag,
  replaceFunc: replaceFuncFlag,
  target,
  dir,
  file
}) => {
  const filePath = (0, _path.join)(modulePath, target, dir, file);
  if (!_fs.default.existsSync(filePath)) return false;
  const middlewareCode = _fs.default.readFileSync(filePath, 'utf-8');
  let start = middlewareCode.indexOf(startFlag);
  let end = middlewareCode.indexOf(endFlag) + endFlag.length;
  // already injected
  if (start > -1 && middlewareCode.indexOf(replaceFuncFlag) === -1) {
    start = -1;
    end = -1;
  }
  if (start === -1) return false;
  _fs.default.writeFileSync(filePath, middlewareCode.substr(0, start) + funcFlag + middlewareCode.substr(end, middlewareCode.length));
  return true;
};
const revert = (modulePath, moduleName) => {
  const info = getModuleInfo(modulePath, moduleName);
  const flagList = getFlag(info.name, info.version);
  if (Array.isArray(flagList)) {
    flagList.some(flag => revertCode(modulePath, flag));
  } else {
    revertCode(modulePath, flagList);
  }
  return true;
};
exports.revert = revert;