"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _fs = _interopRequireDefault(require("fs"));
var _child_process = _interopRequireDefault(require("child_process"));
var _path = _interopRequireDefault(require("path"));
var _chalk = _interopRequireDefault(require("chalk"));
var _injectDevToolsMiddleware = require("./injectDevToolsMiddleware");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const modulePath = _path.default.join(process.cwd(), 'node_modules');
const log = (pass, msg) => {
  const prefix = pass ? _chalk.default.green.bgBlack('PASS') : _chalk.default.red.bgBlack('FAIL');
  const color = pass ? _chalk.default.blue : _chalk.default.red;
  console.log(prefix, color(msg));
};
var _default = (argv, cb) => {
  let moduleName;
  if (argv.macos) {
    moduleName = 'react-native-macos';
  } else {
    moduleName = 'react-native';
  }

  // Revert injection
  if (argv.revert) {
    const passMiddleware = (0, _injectDevToolsMiddleware.revert)(modulePath, moduleName);
    const msg = 'Revert injection of React Native Debugger from React Native packager';
    log(passMiddleware, msg + (!passMiddleware ? ', the file inject file not found.' : '.'));
    return cb(passMiddleware);
  }
  const inject = () => {
    const pass = (0, _injectDevToolsMiddleware.inject)(modulePath, moduleName);
    const msg = 'Replace `open debugger-ui with Chrome` to `open React Native Debugger`';
    log(pass, msg + (pass ? '.' : ', the file inject file not found.'));
    cb(pass);
  };
  if (process.platform !== 'darwin') {
    inject();
  } else {
    const cwd = '/System/Library/Frameworks/CoreServices.framework/Versions/A/Frameworks/LaunchServices.framework/Versions/A/Support/'; // eslint-disable-line
    const lsregisterPath = 'lsregister';
    if (!_fs.default.existsSync(cwd + lsregisterPath)) return inject();
    _child_process.default.exec(`./${lsregisterPath} -dump | grep rndebugger:`, {
      cwd
    }, (err, stdout) => {
      if (stdout.length === 0) {
        log(false, '[RNDebugger] The `rndebugger://` URI scheme seems not registered, ' + "maybe you haven't install the app? " + 'Run `brew update && brew install --cask react-native-debugger` ' + 'or download from https://github.com/jhen0409/react-native-debugger/releases ' + 'then open it to register the URI scheme.');
      }
      inject();
    });
  }
};
exports.default = _default;